@@ -138,4 +138,4 @@ class world(TemplateFormat):
 
     def getConfig(self):
         """Получение текстового файла из XML документа"""
-        return _u("%s\n" % "\n".join(sorted(self.doc)))
+        return "%s\n" % "\n".join(sorted(self.doc))
